Stan Math Library: stan/math/prim/mat/prob/lkj_corr_cholesky_rng.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
lkj_corr_cholesky_rng.hpp File Reference
`#include <stan/math/prim/scal/err/check_finite.hpp>`
`#include <stan/math/prim/scal/err/check_positive.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/prob/beta_rng.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`
`#include <stan/math/prim/mat/fun/factor_cov_matrix.hpp>`
`#include <stan/math/prim/mat/fun/factor_U.hpp>`
`#include <stan/math/prim/mat/fun/read_corr_L.hpp>`
`#include <stan/math/prim/mat/fun/read_corr_matrix.hpp>`
`#include <stan/math/prim/mat/fun/read_cov_L.hpp>`
`#include <stan/math/prim/mat/fun/read_cov_matrix.hpp>`
`#include <stan/math/prim/mat/fun/make_nu.hpp>`
`#include <stan/math/prim/scal/fun/identity_constrain.hpp>`
`#include <stan/math/prim/scal/fun/identity_free.hpp>`
`#include <stan/math/prim/scal/fun/positive_constrain.hpp>`
`#include <stan/math/prim/scal/fun/positive_free.hpp>`
`#include <stan/math/prim/scal/fun/lb_constrain.hpp>`
`#include <stan/math/prim/scal/fun/lb_free.hpp>`
`#include <stan/math/prim/scal/fun/ub_constrain.hpp>`
`#include <stan/math/prim/scal/fun/ub_free.hpp>`
`#include <stan/math/prim/scal/fun/lub_constrain.hpp>`
`#include <stan/math/prim/scal/fun/lub_free.hpp>`
`#include <stan/math/prim/scal/fun/prob_constrain.hpp>`
`#include <stan/math/prim/scal/fun/prob_free.hpp>`
`#include <stan/math/prim/scal/fun/corr_constrain.hpp>`
`#include <stan/math/prim/scal/fun/corr_free.hpp>`
`#include <stan/math/prim/mat/fun/simplex_constrain.hpp>`
`#include <stan/math/prim/mat/fun/simplex_free.hpp>`
`#include <stan/math/prim/mat/fun/ordered_constrain.hpp>`
`#include <stan/math/prim/mat/fun/ordered_free.hpp>`
`#include <stan/math/prim/mat/fun/positive_ordered_constrain.hpp>`
`#include <stan/math/prim/mat/fun/positive_ordered_free.hpp>`
`#include <stan/math/prim/mat/fun/cholesky_factor_constrain.hpp>`
`#include <stan/math/prim/mat/fun/cholesky_factor_free.hpp>`
`#include <stan/math/prim/mat/fun/cholesky_corr_constrain.hpp>`
`#include <stan/math/prim/mat/fun/cholesky_corr_free.hpp>`
`#include <stan/math/prim/mat/fun/corr_matrix_constrain.hpp>`
`#include <stan/math/prim/mat/fun/corr_matrix_free.hpp>`
`#include <stan/math/prim/mat/fun/cov_matrix_constrain.hpp>`
`#include <stan/math/prim/mat/fun/cov_matrix_free.hpp>`
`#include <stan/math/prim/mat/fun/cov_matrix_constrain_lkj.hpp>`
`#include <stan/math/prim/mat/fun/cov_matrix_free_lkj.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<class RNG >
Eigen::MatrixXd | stan::math::lkj_corr_cholesky_rng (const size_t K, const double eta, RNG &rng)

[ Stan Home Page ] © 2011–2016, Stan Development Team.